@@ -1,7 +1,6 @@
 from itertools import groupby
 
 from worker.app.modules.__init__ import Module
-from worker.data.api import API
 from worker.data import operations
 from worker.data.operations import get_config_by_id
 from worker.framework import constants
@@ -92,11 +91,9 @@ class ActivityModule(Module):
         if previous_string == active_string_id:
             return []
 
-        asset_id = self.global_state['asset_id']
         main_structure = self.build_empty_output(first_wits)
 
         warning = None
-        last_document = None
 
         if active_string_type in running_string:
             if active_string_type not in reset_config:
@@ -107,32 +104,17 @@ class ActivityModule(Module):
                 'message': message
             }
 
-            if active_string_type not in reset_config and self.collection:
-                # get the last record
-                worker = API()
-                last_document = worker.get(
-                    path="/v1/data/corva", collection=self.collection, asset_id=asset_id,
-                    sort="{timestamp: -1}", limit=1,
-                ).data
-                last_document = last_document[0] if last_document else None
-        res = self.configure_output_at_config_change(
-            main_structure, active_string_type, active_string_id, warning, last_document
-        )
+        res = self.configure_output_at_config_change(main_structure, active_string_type, active_string_id, warning)
 
         return [res]
 
-    def configure_output_at_config_change(
-        self, main_structure, active_string_type, active_string_id, warning=None, last_document=None
-    ):
+    def configure_output_at_config_change(self, main_structure, active_string_type, active_string_id, warning=None):
         extra_elements = self.create_output_for_new_config(active_string_type, active_string_id)
         main_structure['data'] = operations.merge_dicts(main_structure['data'], extra_elements)
 
         if warning:
             main_structure['data'] = operations.merge_dicts(main_structure['data'], {'warning': warning})
 
-        if last_document:
-            main_structure['data'] = operations.merge_dicts(last_document.get('data', {}), main_structure['data'])
-
         return main_structure
 
     def create_output_for_new_config(self, active_string_type, active_string_id):
