@@ -1,4 +1,4 @@
-import json
+import simplejson as json
 import os
 from typing import List, Literal, Tuple, Union
 
