@@ -1,10 +1,11 @@
-import json
+import simplejson as json
 import os
 
 from worker import API
 from worker.mixins.logging import LoggingMixin
 from worker.mixins.rollbar import RollbarMixin
 from worker.data.enums import LambdaStates
+from worker.data.json_encoder import JsonEncoder
 
 
 class TaskHandler(LoggingMixin, RollbarMixin):
@@ -87,4 +88,4 @@ class TaskHandler(LoggingMixin, RollbarMixin):
         :return:
         """
         path = "/v2/tasks/{0}/{1}".format(task_id, status)
-        self.task = self._api.put(path, data=json.dumps(request_body)).data
+        self.task = self._api.put(path, data=json.dumps(request_body, cls=JsonEncoder, ignore_nan=True)).data
