@@ -1,4 +1,6 @@
-import json
+import simplejson as json
+
+from worker.data.json_encoder import JsonEncoder
 
 
 class State(dict):
@@ -34,7 +36,7 @@ class State(dict):
 
     def to_json(self):
         output = {field: self.get(field, None) for field in self.fields.keys()}
-        output = json.dumps(output)
+        output = json.dumps(output, cls=JsonEncoder, ignore_nan=True)
 
         return output
 
