@@ -31,6 +31,7 @@ class PipeType(Enum):
     CASING_JOINTS = "Casing Joints"
     DV_TOOL = "Differential Valve Tool"
     ACP = "Annular Casing Packer"
+    RISER = "Riser"
 
     @staticmethod
     def determine_type(family: str):
@@ -52,7 +53,8 @@ class PipeType(Enum):
             'toe_sleeve': PipeType.TOE_SLEEVE,
             'casing_joints': PipeType.CASING_JOINTS,
             'dv_tool': PipeType.DV_TOOL,
-            'acp': PipeType.ACP
+            'acp': PipeType.ACP,
+            'riser': PipeType.RISER
         }
         _type = mapping.get(family)
         if not _type:
